@@ -28,6 +28,12 @@ class QPainterPath;
 class QPen;
 class QTransform;
 
+#if KPOPPLER_VERSION >= QT_VERSION_CHECK(0, 83, 0)
+#define GFXPATH_CONST const
+#else
+#define GFXPATH_CONST
+#endif
+
 namespace KItinerary {
 
 /** Utilities for interacting with Poppler. */
@@ -41,7 +47,7 @@ namespace PopplerUtils
     QTransform currentTransform(GfxState *state);
 
     /** Convets a Poppler path into a Qt path. */
-    QPainterPath convertPath(GfxPath *path, Qt::FillRule fillRule);
+    QPainterPath convertPath(GFXPATH_CONST GfxPath *path, Qt::FillRule fillRule);
 }
 
 }
